==> whmcs-9.0.0-release.1.zip: resources/views/marketconnect/layouts/index.php <==
<?php //ICB0 82:0 83:104b                                                     ?><?php //00cba
// *************************************************************************
// *                                                                       *
// * WHMCS - The Complete Client Management, Billing & Support Solution    *
// * Copyright (c) WHMCS Ltd. All Rights Reserved,                         *
// * Version: 9.0.0 (9.0.0-release.1)                                      *
// * BuildId: db1c908403.748                                               *
// * Build Date: 20 Jan 2026                                               *
// *                                                                       *
// *************************************************************************
// *                                                                       *
// * Email: info@whmcs.com                                                 *
// * Website: http://www.whmcs.com                                         *
// *                                                                       *
// *************************************************************************
// *                                                                       *
// * This software is furnished under a license and may be used and copied *
// * only  in  accordance  with  the  terms  of such  license and with the *
// * inclusion of the above copyright notice.  This software  or any other *
// * copies thereof may not be provided or otherwise made available to any *
// * other person.  No title to and  ownership of the  software is  hereby *
// * transferred.                                                          *
// *                                                                       *
// * You may not reverse  engineer, decompile, defeat  license  encryption *
// * mechanisms, or  disassemble this software product or software product *
// * license.  WHMCompleteSolution may terminate this license if you don't *
// * comply with any of the terms and conditions set forth in our end user *
// * license agreement (EULA).  In such event,  licensee  agrees to return *
// * licensor  or destroy  all copies of software  upon termination of the *
// * license.                                                              *
// *                                                                       *
// * Please see the EULA file for the full End User License Agreement.     *
// *                                                                       *
// *************************************************************************
if(extension_loaded('ionCube Loader')){die('The file '.__FILE__." is corrupted.\n");}echo("\nScript error: the ".(($cli=(php_sapi_name()=='cli')) ?'ionCube':'<a href="https://www.ioncube.com">ionCube</a>')." Loader for PHP needs to be installed.\n\nThe ionCube Loader is the industry standard PHP extension for running protected PHP code,\nand can usually be added easily to a PHP installation.\n\nFor Loaders please visit".($cli?":\n\nhttps://get-loader.ioncube.com\n\nFor":' <a href="https://get-loader.ioncube.com">get-loader.ioncube.com</a> and for')." an instructional video please see".($cli?":\n\nhttp://ioncu.be/LV\n\n":' <a href="http://ioncu.be/LV">http://ioncu.be/LV</a> ')."\n\n");exit(199);
?>
HR+cPyz7/xGIHww49MxqgJ4QOH3JTl2kPFJGRiQGZsMND95IwW0N4pXf4cE7nPy8Ypu3n4Pf7dc7
rRD4aGrQ6CXAAFuj2+5izd0AUad6hAb66dWoTNpXIX8ZWBUQPpNcyvhmotLV+j5645xcK+DjSmCn
r44VMGjZ7Cs0TiicEphGxoS52EVYWxbOhDN3wN6b4FrDgSA71XtjuE2NHInVqxDVkCpvezSM3Ou9
uC/LcpScu3cfX+ag6NzMTUPxTNj+PxwFSd4aqGvs1Kq/IG6I730oQadhGGrWtx1W6WL9UvGGdEbg
IbD79cfL2HZ4KWs1Y6z0Ye3pw0t/pntro4ydojB1lwCcG6kPhs9ytlBT+kXwlxn/ZVvSUKF6q2lR
B7UBizeQghs+4tVrv9UyyKd3D0lgjfSE7eXtzLYCyUbFkzEKqUX/zEnzb1awlRqH6rothbz3usCk
kr6wW75ED//cWUJipuWhsZ3t3LMATnEoT3KCxffj46dkSLGAPSXm1lz2Nd/C/7Y+chOOxgmQKEfP
Ruz1SPcAUAJyGT1Kcuo4EsBBdYbHRPwTO9u5hhuHzbTIHEerbmLMDRhqVtpejd0LbkmcMxeW3cQG
Rqso659wdQxBoyAbDRkWTFO4In2/bUF+whUNrzbxS5t4H0iZNhL0t3PCge/j9tlX7g7eyiUmYZPz
Tc5xpJUW1CQWAl8f+MUlsOof3qW5UwdwYg8n/ZYlM2gYRWJi1sRc3/SNCsDuNDnvYyNXk+iomPHt
U9AY+Dg5GTgyxD6JqwbVa1reUIVulHT4esrIOp9OCcZ/bPrbFZBeyZMef2ig4r53iN79NlnF4c5l
GlAXbQg5amDZbGTPpb8gHNy5YxtERQDwdTfZ6sW4qu+X6Uobh6X4mwkKsyZ8=
HR+cPqvkR/WjmbFmMD3wsmOYV0dTdOSCrI/G/Rx8eXpeVm0nkJ/TZLJo3N+tg7F79lF2eHRMSJKd
byPYMw+CBGYNeuKMRFkLJYgnWXAMyl5yYOALzS7WvtKNn5qEZoBDsdbJWUehJiFD7MpYf2Ce0t8z
GPCYd1oz8F9/STEBvme0Uq0KApMVwdCC2WYSmYusLMMjqZULEhEWXA6xcu5DKGK+OfezWILaeQiL
8G9UyHAWbIdRzA0wawwoi7zU7fdeHmOVJHLfEAVyN+GzBfw8AAH/8S0eNUH1bQIfaguz2yDiSNV5
qwfOR8jk/mMKKfdSw2AVZMSDHdpxe0HuNP4gtG1OoFWl7i00COP8p27FGoSR0qpwvJPAW/pNgLHU
qp/TRWZU/fWNxkhrqvUvnY3qSKBlbfjSnVf28iUOeuosjcmrtoAK2/9Gd+D3PRqHWquXqx4E7fmf
u42f3b2nClURrckLmSugMdq+pKHs/by65UIhyg6tXWzuWfGOXG0FIhp+Lqd13z1LkCELy96CHD8U
DlHPKM7+wCZ+aldhKYjOsyEIV8u6OgkRvIZHjA1JWazJjNp+pS/S+wrLs3Noft5djTStmavbw0uo
OQVkAWB9xnE0RsLqR4LSnwBCyR3cAGClFtPFpyaGfVD6EB1jUjWbdr/oeQf0VdnuHEi7QDOlx+mr
+1m41tk9WYJYuHH1pjMBUWQ+9MgjZUae2//tdHBLd0nePa6gzUlLHW5bfJIX6Abvy3TBfX7wedMt
jfz9WMMDeEFwIe6dutWzxjwRTpvR36UF7K1kXxoWcDXQ6f0E8gkJfeKQXszj4Q6LqXEmWzYsvHYs
AJemX92bZPKZ9SP3uaBeG6llYWmOFhWn7IA44cqhJUJXHFUTLxzXm6AuNC0gkxwnzjdUlm==

==> whmcs-9.0.1-release.1.zip: resources/views/marketconnect/layouts/index.php <==
<?php //ICB0 82:0 83:104b                                                     ?><?php //00cba
// *************************************************************************
// *                                                                       *
// * WHMCS - The Complete Client Management, Billing & Support Solution    *
// * Copyright (c) WHMCS Ltd. All Rights Reserved,                         *
// * Version: 9.0.1 (9.0.1-release.1)                                      *
// * BuildId: 81d80f82cb.790                                               *
// * Build Date: 05 Feb 2026                                               *
// *                                                                       *
// *************************************************************************
// *                                                                       *
// * Email: info@whmcs.com                                                 *
// * Website: http://www.whmcs.com                                         *
// *                                                                       *
// *************************************************************************
// *                                                                       *
// * This software is furnished under a license and may be used and copied *
// * only  in  accordance  with  the  terms  of such  license and with the *
// * inclusion of the above copyright notice.  This software  or any other *
// * copies thereof may not be provided or otherwise made available to any *
// * other person.  No title to and  ownership of the  software is  hereby *
// * transferred.                                                          *
// *                                                                       *
// * You may not reverse  engineer, decompile, defeat  license  encryption *
// * mechanisms, or  disassemble this software product or software product *
// * license.  WHMCompleteSolution may terminate this license if you don't *
// * comply with any of the terms and conditions set forth in our end user *
// * license agreement (EULA).  In such event,  licensee  agrees to return *
// * licensor  or destroy  all copies of software  upon termination of the *
// * license.                                                              *
// *                                                                       *
// * Please see the EULA file for the full End User License Agreement.     *
// *                                                                       *
// *************************************************************************
if(extension_loaded('ionCube Loader')){die('The file '.__FILE__." is corrupted.\n");}echo("\nScript error: the ".(($cli=(php_sapi_name()=='cli')) ?'ionCube':'<a href="https://www.ioncube.com">ionCube</a>')." Loader for PHP needs to be installed.\n\nThe ionCube Loader is the industry standard PHP extension for running protected PHP code,\nand can usually be added easily to a PHP installation.\n\nFor Loaders please visit".($cli?":\n\nhttps://get-loader.ioncube.com\n\nFor":' <a href="https://get-loader.ioncube.com">get-loader.ioncube.com</a> and for')." an instructional video please see".($cli?":\n\nhttp://ioncu.be/LV\n\n":' <a href="http://ioncu.be/LV">http://ioncu.be/LV</a> ')."\n\n");exit(199);
?>
HR+cPxSo+VYV7CB/QnQ1RDlLc9uhbux7djNCqUb3YWsYdH9vDhNcsEo4RhBjkuI77E4+8XPoJMMH
sb7Gzrhi76WE/v3c2jmjlTPohDPDp0b5zxUEGgcSND2vmI120+RCCiruvyFONAdx79FlJcDuMbE9
3G9l0jW5vA9pGHfNHiiQMYKEXSe3nBfyGEE+HXaZcMIZfJkPuwFx4JaxLqRUszQXYjGug+m/SULP
ZhyQdoKVzgto1fOKymxU9mauGEiKEdNRlU02l0WGqeLPlR2Fu6lPB9I8/8vzJeYGXWkNqsfTdfTt
yU8V0QTrtK3xfCNakEX5eqW8Nzv+/t0p7VaTdWMAFirQbrMiPJ2FFhvWjK8MRIPQWxXkw8piBIGm
YSjWPbrj+LSLk0XTuxgjcEwgysiqtJsiUunJs79DYJGmaPjsDomXFN7yvkLvU2oU3OY7dtDlUF8a
/9phfGGXRqIz+mwz8hY9hqrIBreoMLy2VqrQJB3l16UWVBbGYxwM9BmrgKbp8x3NwYJHlR7vvd/9
ppzl3VXlyM/3LUbWNtnmEQIXYDJxWjAu3oRhpwglGu+VH8tSwAnxplpu9GDt3qIRwwIebVcT/7It
9+mMg1sjFxTUiWemiXbeRLDDWboK3KIb9Sxn5NdrGYYpGVdx4qR35xTo+1NNyW//WnAWSNFeJmQx
uICp4q4Wm56w1iuXSCQOrQ30Mqwau8bPTWulx7f7iAgAM05GzoFGlK7Y9BgL/+gMv8aqNyNSN3W6
4m9tb+0qr2RhlPu4EmiNI9e33VPTjoO9QpNxu43fgUYUs7SHPdOO1wwmZdxIEU/B8RCTT8prNvID
qu34r8FAHFkgTnm+2j1OWtPE3UizTdxvqSCFlDSvzq1zP9yH6WLIgg2Nq5qC=
HR+cPyseaVpVY6hprXO4tutDIUjYz+UfzJ/gshV8Kpzy0dE0cMSgVK/YbIlgnTtl7GxE79iOfLjT
ca+P44rOZ2vKRE3CkynWwi7vWNxb7ilxP4vFYO5b4CfIHf+Tl+PjV7tsdhTjVsmMvU34eoS16FI+
ls6eb5Dheip55UIeYiMQCdJmVdkrXETntvwmNNOuTvYbnAvPN556P3+Zq+nV0W/eCWe7nex/+XTu
6218LsxWDmsqvo5HeL4eoktos76ICemh/mNoZ2LJiW1ypcWRY+u9+MSuLXnby5SgAYU7OIt6ptUw
Pu68TTUA6JAQyiHJSQbDK1DVEpvAjphygwgPxX1EDyZR1BwcDGqNlZQjh7YaMZIZdSgyWzHpv86z
rPFtuHpUarIrdVRgF/daYiexC+CzK0qcR9kmSC30OD0gwbobnpltVA+wB9jrxJeHPch4nQBQYxUE
KHw17ZWfK1p9tfTO5xn8vu2cJvSDf7R/ioZfVWcRkQ5wpLJJK6vIY3B/LC0UDSzWQBqEuYIoa+Pe
GVaWYpfB5siOE0SrVbhN3a9ZNU+O/GMX8FxQq8Kem9g06WBMQJ1ar8jRxcpIzPJosGdPMWM/sGDK
6A4FTZf2s7Rpt6Xc/WFfmYkhkrbAKGU3hEtpNPkyqwrLadxibqak89Oc4vTIM9dEPwaRc6XxMXwK
mwBEIZatA2tUjVogZj01zFs6/Pyk1QBPykM+0xDxQofRhZggXjd+1LOUJSrqMi44QA6I0BGF+dcV
NbnCV4TkDXLcfzEbJ5wimXwXmLkUFbmxuU7Q9nDragPtAhi6zxAExX4nOLWBMx0flqpG6RVTbVUC
YxrpuxJDRgO2ug+PfBWUG9HtG6VBbEERqTURPPT2Gb8kcp9e1xZya2QFjJgdQjU5xG==
